==> kbudget-0.2.tar.gz: kbudget-0.2/kbudget/knewaccount.h <==
/***************************************************************************
                          knewaccount.h  -  description
                             -------------------
    begin                : Thu Aug 29 2002
    copyright            : (C) 2002 by Richard Garand
    email                : richard@garandnet.net
    $Id: knewaccount.h,v 1.2 2002/09/04 02:04:16 richard Exp $
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KNEWACCOUNT_H
#define KNEWACCOUNT_H

#include <kdialogbase.h>
#include <klineedit.h>
#include <kcombobox.h>
#include <knuminput.h>

class KBudgetApp;

/**Creates a new account dialog box
  *@author Richard Garand
  */

class KNewAccount : public KDialogBase  {
  public: 
    KNewAccount(KBudgetApp* parent);
    ~KNewAccount();
  private:
    /** ok button slot */
    void slotOk();
  
    const KBudgetApp* mainWin;
    KLineEdit* name;
    KComboBox* type;
    KDoubleNumInput* initialBalance;
};

#endif

==> kbudget-0.3.tar.gz: kbudget-0.3/kbudget/knewaccount.h <==
/***************************************************************************
                          knewaccount.h  -  description
                             -------------------
    begin                : Thu Aug 29 2002
    copyright            : (C) 2002 by Richard Garand
    email                : richard@garandnet.net
    $Id: knewaccount.h,v 1.3 2002/09/10 01:02:50 richard Exp $
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KNEWACCOUNT_H
#define KNEWACCOUNT_H

#include <kdialogbase.h>
#include <klineedit.h>
#include <kcombobox.h>
#include <knuminput.h>

class KMainWindow;
class KBudgetDoc;

/**Creates a new account dialog box
  *@author Richard Garand
  */

class KNewAccount : public KDialogBase  {
  public: 
    KNewAccount(KMainWindow* parent, KBudgetDoc* doc, int id = -1);
    ~KNewAccount();
  private:
    /** ok button slot */
    void slotOk();

    KBudgetDoc* doc;
    int account;
    
    KLineEdit* name;
    KComboBox* type;
    KDoubleNumInput* initialBalance;
};

#endif
